@@ -40,7 +40,7 @@
 
 //@line 46 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/app/profile/all-thunderbird.js"
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/9.0");
+pref("general.useragent.extra.thunderbird", "Thunderbird/9.0.1");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
